code stringlengths 2 1.05M | repo_name stringlengths 5 101 | path stringlengths 4 991 | language stringclasses 3
values | license stringclasses 5
values | size int64 2 1.05M |
|---|---|---|---|---|---|
########################################################################################################
# Control the state of your ESXi SSH Server status, and also optionally disable the warning
# Note: I only recommend using this in lab environments, it's not a valid security practice in prod
######################... | discoposse/lab-config | VMware/set-ssh.ps1 | PowerShell | apache-2.0 | 2,016 |
param (
[switch]$AutoStart = $false
)
# Vagrant SSH Keys
Mkdir -Force c:\Users\vagrant\.ssh
(New-Object System.Net.WebClient).DownloadFile('https://raw.githubusercontent.com/mitchellh/vagrant/master/keys/vagrant.pub', 'C:\Users\vagrant\.ssh\authorized_keys')
Write-Output "AutoStart: $AutoStart"
$is_64bit = [IntPtr]... | deluxebrain/play-packer-aws-provisioning | packer-pipeline/scripts/openssh.ps1 | PowerShell | mit | 4,421 |
# psake
# Copyright (c) 2010 James Kovacs
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publ... | ariflagiwale/PSUpdateXml | psake.psm1 | PowerShell | mit | 35,658 |
# Generic module deployment.
#
# ASSUMPTIONS:
#
# * folder structure either like:
#
# - RepoFolder
# - This PSDeploy file
# - ModuleName
# - ModuleName.psd1
#
# OR the less preferable:
# - RepoFolder
# - RepoFolder.psd1
#
# * Nuget key in $ENV:NugetApiKey
#
# * Set-BuildEnvironment from BuildHel... | brianwoelfel/BoxTurtlePs | deploy.psdeploy.ps1 | PowerShell | mit | 1,485 |
try {Import-Module $PSScriptRoot\..\..\ImportExcel.psd1} catch {throw ; return}
PieChart (.\TargetData.ps1) "A PieChart" | dfinke/ImportExcel | Examples/JustCharts/TryPieChart.ps1 | PowerShell | apache-2.0 | 121 |
<# # Documentation {{{
.Synopsis
Installs .Net 3.5
#> # }}}
[CmdletBinding(SupportsShouldProcess=$true)]
Param(
)
begin
{
Write-Output "Script started at $(Get-Date -Format 'yyyy-MM-dd HH:mm:ss')"
$Now = Get-Date -Format 'yyyyMMddHHmmss'
}
process
{
function Show-Elapsed([Diagnostics.StopWatch] $watch) # {{{
... | TheBigBear/packer-windows-gildas | scripts/install-dotnet452.ps1 | PowerShell | apache-2.0 | 2,727 |
#
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements. See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership. The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not... | olamy/archiva | src/ci/scripts/cleanup.ps1 | PowerShell | apache-2.0 | 3,846 |
$packageName = 'adobeshockwaveplayer'
$installerType = 'exe'
$checksum = '7bd7f120eb16aa218c55b5e2b22a63746bdfe9fe'
$checksumType = 'sha1'
$silentArgs = '/S /NCRC'
$validExitCodes = @(0) #please insert other valid exit codes here, exit codes for ms http://msdn.microsoft.com/en-us/library/aa368542(VS.85).aspx
$pwdPath =... | dtgm/chocolatey-packages | automatic/_output/adobeshockwaveplayer/12.1.7.158.pushed/tools/chocolateyInstall.ps1 | PowerShell | apache-2.0 | 1,297 |
ConvertFrom-StringData @'
string1=string1 for en-US
string2=string2 for en-US
'@ # SIG # Begin signature block
| bingbing8/PowerShell | test/powershell/Language/Scripting/en-US/I18n.Tests.psd1 | PowerShell | mit | 113 |
ConvertFrom-StringData @'
TestingConfiguration = Determines if the Microsoft SQL Server Reporting Service instance is installed.
FoundInstance = Found Microsoft SQL Server Reporting Service instance named '{0}'.
InstanceNotFound = Could not find a Microsoft SQL Server Reporting Service instance.
Install... | nabrond/xSQLServer | source/DSCResources/MSFT_SqlRSSetup/en-US/MSFT_SqlRSSetup.strings.psd1 | PowerShell | mit | 1,648 |
function Get-ComputerScreen
{
param(
[Parameter(Mandatory=$True,ValueFromPipeline=$True)]
[String[]]$Computer
)
$result = @()
foreach($c in $Computer)
{
try
{
# best case, windows vista or higher
gwmi WmiMonitorID -Namespace root\wmi -ComputerName $c -ErrorAction Stop | % {
$result += [PSCustom... | cedricdo/PS | Computer/Get-ComputerScreen.ps1 | PowerShell | mit | 2,929 |
# Grab nuget bits, install modules, set build variables, start build.
Get-PackageProvider -Name NuGet -ForceBootstrap | Out-Null
Install-Module PSDepend -Force
Invoke-PSDepend -Force
Set-BuildEnvironment
Invoke-psake .\.build\2.psake.ps1
exit ( [int]( -not $psake.build_success ) ) | RamblingCookieMonster/PowerShell | .build/0.build.ps1 | PowerShell | mit | 286 |
$_bashExe = "c:\cygwin\bin\bash.exe"
$_DdsmRoot = "C:\Code\Data\DATA698-ResearchProj\ddsm"
#$_Output = "C:\Code\Python\DATA698-ResearchProj\data\ddsm\myOutput"
$_OutputRoot = "C:\Users\Dan\Dropbox\DATA698-S17\data\ddsm"
$_PngOutput = $_OutputRoot + "\png"
$_PgmOutput = $_OutputRoot + "\pgm"
$_jpegPath = "/cygdrive/c/c... | jnarhan/Breast_Cancer | src/img_acquistion/Convert-DdsmImages.ps1 | PowerShell | mit | 11,564 |
$WebApplicationUrl = $args[0]
$SiteUrl = $args[1]
$SolutionName = $args[2]
$FeatureName = $args[3]
Add-PSSnapin microsoft.sharepoint.powershell
if ($FeatureName -ne $null)
{
Write-Host "Deactivating feature: $FeatureName - " -NoNewline
if (Get-SPFeature -Site $SiteURL | where {$_.DisplayName -eq $Featu... | boades/ps1-scripts | Deployment/RetractFarmSolution.ps1 | PowerShell | mit | 1,331 |
function Get-OpenVasReportFormats
{
<#
.Synopsis
Return the GUIDs and Report Format Names from an OpenVAS Server
.DESCRIPTION
Return the GUIDs and Report Format (e.g. CSV Hosts or HTML) from an OpenVAS Server
Built with infomation from http://docs.greenbone.net/GSM-Manual/gos-4/en/omp.html#access-with-omp
... | jamesfed/PSOpenVas | Get-OpenVasReportFormats.ps1 | PowerShell | mit | 1,442 |
Import-Module "$PSScriptRoot/../helpers/Common.Helpers.psm1"
Import-Module "$PSScriptRoot/../helpers/Tests.Helpers.psm1" -DisableNameChecking
Import-Module "$PSScriptRoot/../software-report/SoftwareReport.Android.psm1" -DisableNameChecking
$os = Get-OSVersion
Describe "Android" {
$androidSdkManagerPackages... | mattgwagner/New-Machine | .github-actions/images/macos/tests/Android.Tests.ps1 | PowerShell | mit | 4,359 |
#Get public and private function definition files.
$Public = @( Get-ChildItem -Path $PSScriptRoot\Public\*.ps1 -ErrorAction SilentlyContinue )
$Private = @( Get-ChildItem -Path $PSScriptRoot\Private\*.ps1 -ErrorAction SilentlyContinue )
#Dot source the files
Foreach($import in @($Public + $Private))
{... | jeremymcgee73/PSTSM | PSTSM/PSTSM.psm1 | PowerShell | mit | 532 |
#############################################################################
# Copyright (c) Microsoft. All rights reserved.
# Licensed under the MIT license. See LICENSE file in the project root for full license information.
#############################################################################
return $num... | LiuXiaotian/ProtocolTestFramework | src/test/TestAdapter/PowerShell/ReturnInt.ps1 | PowerShell | mit | 325 |
$packageName = 'dolphin'
$url = 'http://dl.dolphin-emu.org/builds/dolphin-master-4.0-9222-x64.7z'
$checksum = 'd9b8e22504f115352dcc81c1a0a2a1ee7c926f75'
$checksumType = 'sha1'
$url64 = $url
$checksum64 = $checksum
$checksumType64 = $checksumType
$toolsDir = "$(Split-Path -parent $MyInvocation.MyCommand.Definition)"
In... | dtgm/chocolatey-packages | automatic/_output/dolphin/4.0.9222/tools/chocolateyInstall.ps1 | PowerShell | apache-2.0 | 761 |
<#
.SYNOPSIS
This PowerShell script module file provides a step function to be used in a
series of executable PowerShell steps that is intended to be included in all
main PowerShell scripts that reside within the automation framework.
.DESCRIPTION
Note: This script module is NOT intended to be executed independent of ... | ChrisJaehnen/dev-tools-script-console | Steps/Install/Install-JavaKeyTrustStore.psm1 | PowerShell | apache-2.0 | 11,883 |
<#
.SYNOPSIS
Run a suite of Azure Key Vault tests via the PowerShell cmdlets.
.PARAMETER TestRunNameSpace
Used as a namespace for each test run. It is used as a substring for key
and vault names during tests, so be sure to keep it short.
.PARAMETER TestMode
The test mode (optional). Must be either 'ControlPlane', 'D... | krkhan/azure-powershell | src/ResourceManager/KeyVault/Commands.KeyVault.Test/Scripts/RunKeyVaultTests.ps1 | PowerShell | apache-2.0 | 32,013 |
ConvertFrom-StringData @'
GettingCertReqStatusMessage = Getting Certificate with Subject '{0}' issued by {1}.
CertificateExistsMessage = Certificate with Subject '{0}' issued by {1} found with thumbprint '{2}'.
StartingCertReqMessage = Starting Certificate request with Subject '{0}' issued by {1}.
C... | puppetlabs/puppetlabs-dsc | lib/puppet_x/dsc_resources/CertificateDsc/DSCResources/MSFT_CertReq/en-US/MSFT_CertReq.strings.psd1 | PowerShell | apache-2.0 | 2,274 |
function Reset-Project($msbuild) {
$imports = $msbuild.Xml.Imports
if ($imports.Count -gt 0) {
foreach ($import in $imports) {
if ($import.Project.IndexOf("ScriptSharp.targets") -gt 0) {
$msbuild.Xml.RemoveChild($import)
}
}
}
}
| LucasOromi/Ratrace.NET | packages/ScriptSharp.0.7.5.1/tools/Reset.psm1 | PowerShell | apache-2.0 | 275 |
#
# Copyright 2019 Google Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in wri... | GoogleCloudPlatform/terraform-sqlserver-alwayson | powershell/c2d/initial_win_startup_script.ps1 | PowerShell | apache-2.0 | 4,864 |
#------------------------------------------------------------------------------#
# Programme: src_connexion.ps1 #
# Description: #
# #
# Auteurs: Robert Bournival, Nic... | Entrepriselinux/crosemont | src_connexion.ps1 | PowerShell | bsd-3-clause | 6,438 |
param(
[Parameter(Mandatory=$True)]
[System.String]
$Directory
)
# SUMMARY
# This script will print all DLLs and PDBs in a given directory.
# This is useful when debugging a hosted build and inspecting if and where expceted artifacts were built.
Write-Host "`nDirectory:" $Directory;
$files = Get-ChildIte... | pharring/ApplicationInsights-dotnet | .scripts/build_ListArtifacts.ps1 | PowerShell | mit | 488 |
<#
.SYNOPSIS
Updates Package Source Url with correct URL in the nuspec file
.DESCRIPTION
It updates the package nuspec file with the correct package source url.
.PARAMETER Name
If specified it only updates the package matching the specified name
.PARAMETER GithubRepository
The github user/repository to use
... | BBTSoftwareAG/chocolatey-packages | scripts/Update-PackageSourceUrl.ps1 | PowerShell | mit | 5,268 |
$projectRoot = Resolve-Path "$PSScriptRoot\.."
$moduleRoot = Split-Path (Resolve-Path "$projectRoot\*\*.psd1")
$moduleName = Split-Path $moduleRoot -Leaf
$modulePath = (Join-Path $moduleRoot "$moduleName.psd1")
Write-Host "projectRoot: $projectRoot" -f cyan
Write-Host "moduleRoot: $moduleRoot" -f cyan
Write-Host "mo... | Sam-Martin/servicenow-powershell | Tests/Unit.GenericModule.Tests.ps1 | PowerShell | apache-2.0 | 3,578 |
$packageName = 'kicad'
$installerType = 'exe'
$silentArgs = '/S'
$url = 'http://www2.futureware.at/~nickoe/kicad-product-r5762.d3b3131-i686.exe'
$checksum = 'ce50d0b270eaf8a2dbcab9b93aab05e29298bbb5'
$checksumType = 'sha1'
$url64 = 'http://www2.futureware.at/~nickoe/kicad-product-r5762.d3b3131-x86_64.exe'
$checksum64 =... | dtgm/chocolatey-packages | automatic/_output/kicad/2015.06.16.5762/tools/chocolateyInstall.ps1 | PowerShell | apache-2.0 | 946 |
$script:cacheFiles = (property cacheFiles "")
task ReplaceCacheBust {
Update-CacheBust $basePath\$projectName $cacheFiles "cacheBuster"
}
function script:Update-CacheBust($projectPath, $cacheFiles, $cacheBusterPattern) {
$cacheFiles.Split(";") | foreach {
Write-Host "Replacing the cache busters in $_"
... | Kennethtruyers/PowerTasks | PowerTasks/.Tasks/ReplaceCacheBust.ps1 | PowerShell | mit | 440 |
$Title = "VSAN Configuration Maximum VMs Per VSAN Cluster Report"
$Header = "VSAN Config Max - VMs Per VSAN Cluster"
$Display = "Table"
$Author = "William Lam"
$PluginVersion = 1.1
$PluginCategory = "vSphere"
# Start of Settings
# Percentage threshold to warn?
$vsanWarningThreshold = 50
# End of Settings
# Update se... | Sneddo/vCheck-vSphere | Plugins/40 Datastore/997 VSAN Configuration Maximum VMs Per Cluster Report.ps1 | PowerShell | mit | 1,250 |
param
(
[Parameter(Mandatory=$false)]
[string] $SearchPattern
)
$ErrorActionPreference = "Stop";
Set-StrictMode -Version "Latest";
$thisScript = $MyInvocation.MyCommand.Path;
$thisFolder = [System.IO.Path]::GetDirectoryName($thisScript);
Import-Module -Name ([System.IO.Path]::Combine($thisFolder, "StepTempla... | red-gate/Library | tools/_pack.ps1 | PowerShell | apache-2.0 | 997 |
# Usage: concfg presets
# Summary: List builtin available presets
# Help: Lists the presets that are available for the 'concfg import' command
. "$PSScriptRoot\..\lib\presets.ps1"
$result = Get-BuiltinPreset
Write-Output "Available presets:"
Format-PresetOutput($result)
| codeimpossible/dotfiles | powershell/concfg/libexec/presets.ps1 | PowerShell | mit | 273 |
#
# Unmount-ImageFile.ps1
#
# This function will unmount a wim or vhd file using DISM.
Function Unmount-ImageFile
{
[CmdletBinding()]
Param (
[Parameter(Mandatory=$true,Position=0)]
[string]$MountDir
)
# Verify the mount directory exists
Begin
{
if (Test-Path $MountDir)
{
Write-Verbose "$MountDir ex... | TechnologyEnthusiast/powershell-unmount-imagefile | Unmount-ImageFile.ps1 | PowerShell | mit | 940 |
<#
.SYNOPSIS
SCCM Uninstall program for 7300 RealTime PCR System (32-bit)
.DESCRIPTION
Remove the following component(s) from Window 7 x64 systems:
- 7300 RealTime PCR System
- Install folder
- WINXPSP2 compatibility setting – installer
- WINXPSP2 compatibility set... | jrsenff/Sccm-PowerShell-Scripts | 7300 RealTime PCR System - Manual/7300RealTimePCRSystem_Manual_Uninstall.ps1 | PowerShell | mit | 5,270 |
<#
.SYNOPSIS
Installs Kodi addons.
.DESCRIPTION
This cmdlet can be use to install or more addons into an existing Raspberry Pi Kodi installation.
This cmdlet expects the addons to be in a zipped (.zip) format, also the cmdlet does a basic validation of the addons structure.
.EXAMPLE
PS /> Install-Plugi... | juniinacio/RaspberryPi-PoSh | RaspberryPi-PoSh/Functions/Install-Plugin.ps1 | PowerShell | mit | 8,241 |
properties {
$base_directory = Resolve-Path ..
$publish_directory = "$base_directory\publish-net40"
$build_directory = "$base_directory\build"
$src_directory = "$base_directory\src"
$output_directory = "$base_directory\output"
$packages_directory = "$src_directory\packages"
$sln_file = "$src_directory\NEvent... | chris-evans/NEventStore | build/default.ps1 | PowerShell | mit | 3,712 |
################################################################################
# Prepackage.ps1
#
# This script generates the chocolatey install and uninstall powershell scripts
# found in the Tools directory in the chocolatey package.
#
# It reads template files fond in the ToolsTemplates directory and replaces
# t... | MasterDevs/ctc | ctc/Chocolatey/PrePackage.ps1 | PowerShell | mit | 2,612 |
#####
# WINDOWS SERVER BOOTSTRAP SCRIPT FOR puppet
#
# bootstrap script mostly inspired by the following links:
# https://stackoverflow.com/a/9949909/682912
# https://gist.githubusercontent.com/masterzen/6714787/raw
####
Start-Transcript -Path 'c:\bootstrap-transcript.txt' -Force
# strict mode for syntax
Set... | agilityroots/biztalk-provisioner | scripts/install.ps1 | PowerShell | mit | 6,996 |
function Get-TSProcess
{
<#
.SYNOPSIS
Gets a list of processes running in a specific session or in all sessions.
.DESCRIPTION
Use Get-TSProcess to get a list of session processes from a local or remote computers.
.PARAMETER ComputerName
The name of the terminal server computer. The default is the loc... | lazywinadmin/LazyTS | source/functions/Get-TSProcess.ps1 | PowerShell | mit | 4,933 |
function Get-SolutionRoot
{
return (Resolve-Path "$PSScriptRoot\..\..\..\").Path
} | lordmilko/PrtgAPI | build/CI/Helpers/Get-SolutionRoot.ps1 | PowerShell | mit | 86 |
Function ConvertTo-QueryString {
<#
.SYNOPSIS
Converts Hashtable to a string for use as a url query string
.DESCRIPTION
When given a hashtable as input, converts key value pairs to query string
.PARAMETER Parameters
Hashtable containing parameter names and values to include in output string
.PARAMETER NoEscape
Spec... | pspete/psPAS | psPAS/Private/ConvertTo-QueryString.ps1 | PowerShell | mit | 1,596 |
#requires -Version 1
@{
AllNodes = @(
@{
NodeName = 'LocalHost'
PSDscAllowPlainTextPassword = $true
Website = 'Website'
ApplicationType = 'WebsiteApplicationType'
ApplicationPool = 'De... | Byte-666/xWebAdministration | Tests/Integration/MSFT_xWebsite.config.psd1 | PowerShell | mit | 1,746 |
# Replace address and port with your server's
# You can edit the script URL if you are hosting it somewhere else
$address = 'localhost'
$port = 8000
$scriptURL = 'https://raw.githubusercontent.com/sweetsoftware/ReversePowershell/master/client.ps1'
$autorunKeyName = "Windows Powershell"
$autorunKeyVal = 'powershell -Wi... | sweetsoftware/ReversePowershell | client.ps1 | PowerShell | mit | 2,127 |
#==============================================================================
#
# FILE: EnterNetwork.psm1
# USAGE: Import-Module EnterNetwork.psm1
# DESCRIPTION: Add a new network to QIP
#
# OPTIONS: ---
# REQUIREMENTS: ---
# BUGS: ---
# NOTES: ---
# ... | cws-khuntly/powershell | WindowsPowerShell/QIP/Modules/QIP-AddNetwork/Modules/EnterNetwork.psm1 | PowerShell | apache-2.0 | 2,313 |
$ErrorActionPreference = 'Stop'
$packageName = ''
$softwareNamePattern = ''
[array] $key = Get-UninstallRegistryKey $softwareNamePattern
if ($key.Count -eq 1) {
$key | % {
$packageArgs = @{
packageName = $packageName
silentArgs = "/x86=0 /S"
... | kkzinger/chocolatey-packages-new | automatic/_template/tools/chocolateyUninstall.ps1 | PowerShell | apache-2.0 | 1,037 |
$packageName = 'csvfileview'
$url = 'http://www.nirsoft.net/utils/csvfileview.zip'
$checksum = 'ec7d5bd4c87bdbf5505f0646366acead4773abf3'
$checksumType = 'sha1'
$toolsDir = "$(Split-Path -parent $MyInvocation.MyCommand.Definition)"
$installFile = Join-Path $toolsDir "$($packageName).exe"
Install-ChocolateyZipPackage -... | dtgm/chocolatey-packages | automatic/_output/csvfileview/2.25/tools/chocolateyInstall.ps1 | PowerShell | apache-2.0 | 672 |
configuration SQLInstanceInstallationConfiguration
{
param
(
[parameter(Mandatory = $true)]
[ValidateNotNullOrEmpty()]
[String] $MySQLInstancePackagePath,
[parameter(Mandatory = $true)]
[ValidateNotNullOrEmpty()]
[String] $MySQLInstancePackageName
... | cyberious/puppetlabs-dsc | lib/puppet_x/dsc_resources/xMySql/Examples/Sample_InstallMySQL_Default.ps1 | PowerShell | apache-2.0 | 1,468 |
$zipFilePath = "$pwd\Target.zip"
del "$pwd\SourceDir-1" -Force -Recurse -ErrorAction SilentlyContinue
del "$pwd\SourceDir-2" -Force -Recurse -ErrorAction SilentlyContinue
New-Item $pwd\SourceDir-1 -Type Directory | Out-Null
New-Item $pwd\SourceDir-1\Sample-1.txt -Type File | Out-Null
New-Item $pwd\SourceDir-... | cyberious/puppetlabs-dsc | lib/puppet_x/dsc_resources/xPSDesiredStateConfiguration/Examples/Test_Sample_xArchive_CompressMultipleDirs.ps1 | PowerShell | apache-2.0 | 1,061 |
$project = Get-MSBuildProject
function Remove-Target($Name)
{
Write-Host "Removing the $Name target from the project..."
$target = $($project.Xml.Targets | where { $_.Name -ieq $Name })
if($target -ne $null)
{
$project.Xml.RemoveChild($target)
}
}
function Remove-Import($PartialMatch)
{
Write-Ho... | andyalm/assman | src/Assman.Mvc/NuGet/Tools/Uninstall.ps1 | PowerShell | bsd-3-clause | 888 |
# Loop every 10 seconds until GroupyConfig.exe is found and killed.
$processNames = @("GroupyConfig")
$killedNames = @()
while ( !($processNames -eq $killedNames)) {
foreach ($process in $processNames) {
if (Get-Process $process -ErrorAction SilentlyContinue) {
Write-Output "$process found,... | rasmuskriest/Chocolatey-Packages | groupy/tools/groupykillprocess.ps1 | PowerShell | mit | 532 |
ConvertFrom-StringData -StringData @'
GettingiSCSIInitiatorMessage = Getting iSCSI Initiator '{0}', '{1}' from '{2}'.
iSCSITargetPortalExistsMessage = iSCSI Target Portal '{0}' from '{1}' exists.
iSCSITargetPortalDoesNotExistMessage = iSCSI Target Portal '{0}' from '{1}' does not exist.
iSCSITargetExist... | PlagueHO/ciSCSI | source/DSCResources/DSC_iSCSIInitiator/en-US/DSC_iSCSIInitiator.strings.psd1 | PowerShell | mit | 3,428 |
#!/usr/bin/env pwsh
[cmdletbinding()]
param(
[Parameter(Mandatory=$true)]
[DateTime]$since);
$engine = & "$PSScriptRoot\dump_commits_since.ps1" -repo space-wizards/RobustToolbox -since $since
$content = & "$PSScriptRoot\dump_commits_since.ps1" -repo space-wizards/space-station-14 -since $since
($content... | space-wizards/space-station-14-content | Tools/dump_contributors_since.ps1 | PowerShell | mit | 485 |
# EMACS settings: -*- tab-width: 2; indent-tabs-mode: t -*-
# vim: tabstop=2:shiftwidth=2:noexpandtab
# kate: tab-width 2; replace-tabs off; indent-width 2;
#
# ==============================================================================
# PowerShell Script: Wrapper Script to execute <PoC-Root>/py/Configuration.py
#... | hoangt/PoC | poc.ps1 | PowerShell | apache-2.0 | 2,320 |
# ************************************************************************
# *
# * Copyright 2016 OSIsoft, LLC
# * Licensed under the Apache License, Version 2.0 (the "License");
# * you may not use this file except in compliance with the License.
# * You may obtain a copy of the License at
# *
# * <http://www.apach... | hpaul-osi/PI-Security-Audit-Tools | PISecurityAudit/Scripts/UpdateValidationsInHelp.ps1 | PowerShell | apache-2.0 | 3,018 |
<#
Copyright (c) 2012-2014 VMware, Inc.
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribu... | Zhi98/webcommander | powershell/Broker/brokerAddLinkedClonePool.ps1 | PowerShell | mit | 4,834 |
Param(
[string]$Script = "build.cake",
[string]$Target = "Default",
[ValidateSet("Release", "Debug")]
[string]$Configuration = "Release",
[ValidateSet("Quiet", "Minimal", "Normal", "Verbose", "Diagnostic")]
[string]$Verbosity = "Verbose",
[switch]$Experimental,
[switch]$WhatIf,
[swit... | AngleSharp/AngleSharp.Scripting | build.ps1 | PowerShell | mit | 2,370 |
$packageName = 'regscanner.install'
$packageSearch = 'Nirsoft regscanner'
$installerType = 'exe'
$silentArgs = '/S'
$validExitCodes = @(0)
try {
Get-ItemProperty -Path @( 'HKLM:\Software\Wow6432Node\Microsoft\Windows\CurrentVersion\Uninstall\*',
'HKLM:\Software\Microsoft\Windows\CurrentVer... | dtgm/chocolatey-packages | automatic/_output/regscanner.install/2.16/tools/chocolateyUninstall.ps1 | PowerShell | apache-2.0 | 978 |
# ----------------------------------------------------------------------------------
#
# Copyright Microsoft Corporation
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# http://www.apache.org... | atpham256/azure-powershell | tools/InstallationTests/NetcoreTests/Compute/DiskRPTests.ps1 | PowerShell | apache-2.0 | 7,439 |
# Sandcastle build script overrides for prototype doc model.
. $DxRoot\Presentation\Shared\SharedDocModel.ps1
function PostProcessReflectionData($sourceFile, $targetFile) {
WriteInfo "Post processing reflection data."
&$XslTransform $sourceFile `
/xsl:$DxRoot\ProductionTransforms\ApplyPrototypeDocModel.... | pwelter34/NLog | tools/Sandcastle/Presentation/Prototype/DocModel.ps1 | PowerShell | bsd-3-clause | 627 |
import-module au
function global:au_SearchReplace {
@{
'dotPeek.nuspec' = @{
"(^.+version=`")(\[.*\])(`".+$)" = "`$1[$($Latest.PlatformVersion)]`$3"
}
'tools\chocolateyInstall.ps1' = @{
"(^[$]filename\s*=\s*)([`"'].*[`"'])" = "`$1'$($Latest.Filename)'"
... | flcdrg/au-packages | dotPeek/update.ps1 | PowerShell | mit | 604 |
function Set-DbaDbState {
<#
.SYNOPSIS
Sets various options for databases, hereby called "states"
.DESCRIPTION
Sets some common "states" on databases:
- "RW" options (ReadOnly, ReadWrite)
- "Status" options (Online, Offline, Emergency, plus a special "Detached")
- "A... | wsmelton/dbatools | functions/Set-DbaDbState.ps1 | PowerShell | mit | 21,439 |
Install-VisualStudio `
-PackageName 'visualstudio2022testagent-preview' `
-ApplicationName 'Microsoft Visual Studio Test Agent 2022 Preview' `
-Url 'https://download.visualstudio.microsoft.com/download/pr/c49cd33e-1d0a-4bac-b9f8-70c66db3e1c4/6b5316ca1a98bba0e9e2be7e524ef3ac9219832a96dfa9dc29bc5c555bc29442/... | jberezanski/ChocolateyPackages | visualstudio2022testagent-preview/tools/ChocolateyInstall.ps1 | PowerShell | mit | 628 |
#Requires -Version 3
function Protect-RubrikNutanixVM
{
<#
.SYNOPSIS
Connects to Rubrik and assigns an SLA to a virtual machine
.DESCRIPTION
The Protect-RubrikNutanixVM cmdlet will update a virtual machine's SLA Domain assignment within the Rubrik cluster.
The SLA Domain con... | rubrikinc/PowerShell-Module | Rubrik/Public/Protect-RubrikNutanixVM.ps1 | PowerShell | mit | 4,088 |
function Get-EXRAppOnlyToken
{
[CmdletBinding()]
param (
[Parameter(Position = 1, Mandatory = $false)]
[string]
$CertFileName,
[Parameter(Position = 2, Mandatory = $false)]
[string]
$TenantId,
[Parameter(Position = 3, Mandatory = $false)]
[string]
$ClientId,
[Parameter(Position = 4, Ma... | gscales/Exch-Rest | functions/oAuth/Get-EXRAppOnlyToken.ps1 | PowerShell | mit | 4,204 |
$script:dscModuleName = 'xActiveDirectory'
$script:dscResourceName = 'MSFT_xADServicePrincipalName'
#region HEADER
# Unit Test Template Version: 1.2.4
$script:moduleRoot = Split-Path -Parent (Split-Path -Parent $PSScriptRoot)
if ( (-not (Test-Path -Path (Join-Path -Path $script:moduleRoot -ChildPath 'DSCResource.Test... | jaredhaight/WindowsAttackAndDefenseLab | WindowsAttackAndDefenseLab/DSC/DomainConfig/xActiveDirectory/Tests/Unit/MSFT_xADServicePrincipalName.Tests.ps1 | PowerShell | mit | 9,043 |
C:\Python27\python.exe setup.py install
# If this is a build because of a tag, make sure that
# its either a testing tag or a tag that matches the version
# specified in the source code.
If ($(APPVEYOR_REPO_TAG) -Match "true") {
If ($(APPVEYOR_REPO_TAG_NAME) -Like "test*") {
exit 0
}
# non-testing tags ... | DaveA50/lbry | packaging/windows/install.ps1 | PowerShell | mit | 462 |
##################################################################################
#
#
# Script name: Add-SPFolder.ps1
#
# Author: niklas.goude@zipper.se
# Homepage: www.powershell.nu
# Company: www.zipper.se
#
##################################################################################
param([str... | borkit/scriptdump | PowerShell/Working/SharePoint/MOSS2007/powershell.nu_moss2007_script_collection/Add-SPFolder.ps1 | PowerShell | mit | 1,451 |
function Say { param( [string] $message )
Write-Host "$(Get-Elapsed) " -NoNewline -ForegroundColor Magenta
Write-Host "$message" -ForegroundColor Yellow
}
function Get-Elapsed
{
if ($Global:startAt -eq $null) { $Global:startAt = [System.Diagnostics.Stopwatch]::StartNew(); }
... | devizer/Universe.SqlTrace | Info/Store-Logs-2.ps1 | PowerShell | mit | 1,312 |
<#
.EXAMPLE
This example provisions the user profile sync service to the local server
#>
Configuration Example
{
param(
[Parameter(Mandatory = $true)]
[PSCredential]
$SetupAccount,
[Parameter(Mandatory = $true)]
[PSCredential]
... | mrpullen/xSharePoint | Modules/SharePointDsc/Examples/Resources/SPUserProfileSyncService/1-Example.ps1 | PowerShell | mit | 838 |
@{
Param1 = 'Config from Common Datum'
} | gaelcolas/SharedDScConfig | SharedDscConfig/DscResources/Shared1/ConfigData/default/SharedDscConfig.psd1 | PowerShell | mit | 44 |
#Requires -Module ActiveDirectory
#Requires -version 3.0
<#PSScriptInfo
.VERSION 2019.16.5
.GUID 242ff6b3-bde7-4a9a-b29e-667a22cc0f7c
.AUTHOR Chad.Cox@microsoft.com
https://blogs.technet.microsoft.com/chadcox/
https://github.com/chadmcox
.COMPANYNAME
.COPYRIGHT This Sample Code is provided for the purpos... | chadmcox/ADPoSh | Users/findADUserswithLogonhours.ps1 | PowerShell | mit | 1,743 |
#CHECK SECURITY UPDATES ON SERVERS IN FARM
#DESCRIPTION:
#NOTES:
function CheckUpdates(){
$Servers = "<severname>", "<severname>", "<severname>"
foreach ($Server in $Servers){
$filepath = "D:\" + $Server + "_securityupdate.csv"
Get-WmiObject -Authentication PacketPrivacy -Impersonation Impersonate -Cla... | kambridge/PowerShell | Reports/securityupdates.ps1 | PowerShell | mit | 791 |
#example 1:
Get-Counter "\Processor(_Total)\% Processor Time" -Continuous
#example 2:
Get-WmiObject Win32_Processor | select LoadPercentage
#example 3:
function Get-ProcessorUsage {
param(
[Parameter(
Position=0,
ValueFromPipelineByPropertyName=$true,
Mandatory=$true)]
[String]$Name
... | mikepfeiffer/ex-2010-ps-cookbook | Chapter12/CheckingCPUUtilization.ps1 | PowerShell | mit | 1,591 |
$PackageName = 'neo4j-community'
# Per-package parameters
$downloadUrl = 'http://neo4j.com/artifact.php?name=neo4j-community-3.4.0-alpha06-windows.zip'
$md5Checksum = '91577244a1572163e68a57f19aa84d57'
$neozipSubdir = 'neo4j-community-3.4.0-alpha06'
# major.minor.update.build
# Build is always 14
$privateJavaVersion = ... | glennsarti/neo4j-community-chocolatey | neo4j-community-3.4.0-alpha06/tools/chocolateyInstall.ps1 | PowerShell | mit | 12,077 |
$packageName = 'vcredist2017'
$installerType = 'exe'
$url = 'https://download.microsoft.com/download/e/6/6/e66c5871-7afe-4640-a454-786eabe8aae8/vc_redist.x86.exe'
$checksum = 'fdccb907365a76e94b9ddc36538a35709688528f03283047f660aa2cb9bcbb1a'
$checksumType = 'sha256'
$url64 = 'https://download.microsoft.com/download/7/... | lennartb-/chocolatey-coreteampackages | manual/vcredist2017/tools/chocolateyInstall.ps1 | PowerShell | apache-2.0 | 1,881 |
$ErrorActionPreference = 'Stop'
$scriptDir=$toolsDir = $(Split-Path -parent $MyInvocation.MyCommand.Definition)
. (Join-Path $scriptDir 'helper.ps1')
$version = "89.0.4388.0-snapshots"
$hive = "hkcu"
$chromium_string = "\SOFTWARE\Microsoft\Windows\CurrentVersion\Uninstall\Chromium"
$Chromium = $hive + ":" + $chromium... | pascalberger/chocolatey-coreteampackages | automatic/chromium/tools/chocolateyInstall.ps1 | PowerShell | apache-2.0 | 1,160 |
$packageName = 'superantispyware'
$installerType = 'exe'
# ver 6.0.1194 fails on 8.1-64
#$silentArgs = '/SILENT'
$silentArgs = ''
$url = 'http://cdn.superantispyware.com/SUPERAntiSpyware.exe'
$checksum = 'fd01b541cd6bfaa503ed8317279c74ea353b145724d3426947798bf017fca981'
$checksumType = 'sha256'
$validExitCodes = @(0)
... | dtgm/chocolatey-packages | automatic/_output/superantispyware/6.0.1230/tools/chocolateyInstall.ps1 | PowerShell | apache-2.0 | 876 |
$systemUnderTest = ( Split-Path -Leaf $MyInvocation.MyCommand.Path ) -replace '\.Tests\.', '.'
$filePath = Join-Path -Path $CI_MODULE_LIB_PATH -ChildPath 'ArmorTypes.ps1'
. $filePath
$class = $systemUnderTest.Split( '.' )[0]
$describe = $Global:FORM_CLASS -f $class
Describe -Name $describe -Tag 'Class', $class -Fixtu... | tlindsay42/ArmorPowerShell | tests/lib/ArmorSessionUser.Tests.ps1 | PowerShell | apache-2.0 | 5,019 |
function Set-TrackingServerHostsEntries {
[CmdletBinding()]
param(
[Parameter(Mandatory=$true)]
[ValidateSet("Add","Remove")]
[string] $Action,
[string[]] $Hosts)
if (!$Hosts) {
$Hosts = Get-Content (Join-Path $PSScriptRoot hosts)
}
$Path = [IO.Path]::Combin... | nathan-alden/windows-10-tracking | Source/Scripts/Set-TrackingServerHostsEntries.ps1 | PowerShell | apache-2.0 | 1,662 |
#
# Copyright (c) Microsoft Corporation.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR AN... | devrandorfer/ScorchDev | PowerShellModules/PackageManagementProviderResource/1.0.2/DSCResources/MSFT_PackageManagementSource/MSFT_PackageManagementSource.strings.psd1 | PowerShell | mit | 1,769 |
#
# Module manifest for module 'Az.DeviceProvisioningServices'
#
# Generated by: Microsoft Corporation
#
# Generated on: 5/18/2018
#
@{
# Script module or binary module file associated with this manifest.
# RootModule = ''
# Version number of this module.
ModuleVersion = '0.4.0'
# Supported PSEditions
CompatiblePSE... | ClogenyTechnologies/azure-powershell | src/ResourceManager/DeviceProvisioningServices/Commands.DeviceProvisioningServices/Az.DeviceProvisioningServices.psd1 | PowerShell | apache-2.0 | 6,030 |
<#
Copyright 2014 ASOS.com Limited
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing... | POSHChef/POSHChef | functions/Configuration/Get-Configuration.ps1 | PowerShell | apache-2.0 | 5,826 |
function Remove-DbaServerRole {
<#
.SYNOPSIS
Deletes specified server-level role.
.DESCRIPTION
Deletes specified server-level role.
.PARAMETER SqlInstance
The target SQL Server instance or instances.
.PARAMETER SqlCredential
Login to the target instance using alter... | kozloski/dbatools | functions/Remove-DbaServerRole.ps1 | PowerShell | mit | 3,867 |
# -----------------------------------------------------------------------
# Copyright : GSoft @2014
# Model : Cross Site Publishing CMS
# File : Setup-ContentTypes.ps1.template
# Description : Create content types structure
# -----------------------------------------------------------------------
Write-W... | GSoft-SharePoint/Dynamite-Components | Source/GSoft.Dynamite.Models.StandardPublishingCMS/Modules/Migration/MIG_01/Setup-ContentTypes.template.ps1 | PowerShell | mit | 537 |
param (
[string]$environmentName,
[string]$resourceFilteringMethod,
[string]$machineNames,
[string]$scriptPath,
[string]$scriptArguments,
[string]$initializationScriptPath,
[string]$runPowershellInParallel,
[string]$sessionVariables
)
Write-Verbose "Entering script PowerShellOnTarge... | robrich/vso-agent-tasks | Tasks/PowerShellOnTargetMachines/PowerShellOnTargetMachines.ps1 | PowerShell | mit | 20,297 |
$CommandName = $MyInvocation.MyCommand.Name.Replace(".Tests.ps1", "")
Write-Host -Object "Running $PSCommandPath" -ForegroundColor Cyan
. "$PSScriptRoot\constants.ps1"
Describe "$CommandName Unit Tests" -Tag 'UnitTests' {
Context "Validate parameters" {
[object[]]$params = (Get-Command $CommandName).Parame... | alevyinroc/dbatools | tests/Set-DbaCmConnection.Tests.ps1 | PowerShell | mit | 1,411 |
param($installPath, $toolsPath, $package, $project)
$DTE.ItemOperations.Navigate("http://xsockets.net/release-notes/?" + $package.Id + "=" + $package.Version) | perfahlen/XSockets.Geo | packages/XSockets.Server.5.7.1/tools/install.ps1 | PowerShell | mit | 159 |
foreach ($attribute in $attributes) {
$FilterTemplate = Get-Variable -Name "$($Attribute.AttributeType)FilterTemplate" -ValueOnly -ErrorAction SilentlyContinue
if ($FilterTemplate -eq $null){
$FilterTemplate = $DefaultFilterTemplate
}
Invoke-Template -Template $FilterTemplate -TemplateMode... | kabtoffe/xrm-powershell-advanced-function-generator | XrmFunctionGenerator/Templates/Get/FilteringLogic.ps1 | PowerShell | mit | 370 |
#begin
# Update with the name of your subscription.
$SubscriptionName="YourSubscriptionName"
# Give a name to your new storage account. It must be lowercase!
$StorageAccountName="yourstorageaccountname"
# Choose "West US" as an example.
$Location = "West US"
# Give a name to your new container.
$Container... | zaiboot/powershell-script-collection | Delete Storage Azure.ps1 | PowerShell | mit | 1,697 |
#!/usr/bin/env pwsh
param(
# Version of .NET Core to filter by
[string]$Version = "*",
# Name of OS to filter by
[string]$OS,
# Type of architecture to filter by
[string]$Architecture,
# Additional custom path filters (overrides Version)
[string[]]$Paths,
# Additional args to pas... | MichaelSimons/dotnet-docker | build-and-test.ps1 | PowerShell | mit | 2,289 |
Remove-VisualStudioWorkload `
-PackageName 'visualstudio2017-workload-managedgame' `
-Workload 'ManagedGame' `
-VisualStudioYear '2017' `
-ApplicableProducts @('Community', 'Professional', 'Enterprise')
| jberezanski/ChocolateyPackages | visualstudio2017-workload-managedgame/tools/ChocolateyUninstall.ps1 | PowerShell | mit | 222 |
function Test-DbaNetworkLatency {
<#
.SYNOPSIS
Tests how long a query takes to return from SQL Server
.DESCRIPTION
This function is intended to help measure SQL Server network latency by establishing a connection and executing a simple query. This is a better than a simple p... | sqlpadawan/dbatools | functions/Test-DbaNetworkLatency.ps1 | PowerShell | mit | 6,500 |
$moduleRoot = Split-Path `
-Path $MyInvocation.MyCommand.Path `
-Parent
#region LocalizedData
$Culture = 'en-us'
if (Test-Path -Path (Join-Path -Path $moduleRoot -ChildPath $PSUICulture))
{
$Culture = $PSUICulture
}
Import-LocalizedData `
-BindingVariable LocalizedData `
-Filename Jenkins_Localizat... | kwsoft/jenkins | Jenkins.psm1 | PowerShell | mit | 77,664 |
#This section provides a script that allows you to provision multiple site collections in SharePoint Online based on a CSV file
#SharePoint Online Url Prefix
$spoUrlPrefix = "https://eskaggsdemo2.sharepoint.com/sites/"
#Default SharePoint Site Collection Owner
$siteOwner = "admin@eskaggsdemo2.onmicrosoft.com"
#Defau... | skaggej/2014-SPSPHX-Content | LiveDemo_createscs.ps1 | PowerShell | mit | 1,238 |
Remove-Module -Name 'Rubrik' -ErrorAction 'SilentlyContinue'
Import-Module -Name './Rubrik/Rubrik.psd1' -Force
foreach ( $privateFunctionFilePath in ( Get-ChildItem -Path './Rubrik/Private' | Where-Object extension -eq '.ps1').FullName ) {
. $privateFunctionFilePath
}
Describe -Name 'Public/Sync-RubrikTag' -Tag ... | rubrikinc/PowerShell-Module | Tests/Sync-RubrikTag.Tests.ps1 | PowerShell | mit | 1,326 |
$ErrorActionPreference = 'Stop'; #Stop on all errors
$packageName = 'automiserunner' #Unique name of the package
$installerType = 'EXE' #Installer is an executable.
$url = '%PRODUCT_DOWNLOAD_URL%' #URL to download installer for current version.
$silentArgs = '/SP /VERYSILENT /SUPPRESSMSGBOXES /CLOSEAPPLICATIONS' #S... | VSoftTechnologies/ChocolateyPackages | automiserunner5/tools/chocolateyinstall.ps1 | PowerShell | apache-2.0 | 673 |
[cmdletbinding()]
param()
# Arrange.
. $PSScriptRoot\..\..\lib\Initialize-Test.ps1
Register-Mock Convert-String { [bool]::Parse($args[0]) }
Register-Mock Get-SolutionFiles { 'Some solution 1', 'Some solution 2' } -- -Solution 'Some input solution'
Register-Mock Format-MSBuildArguments { 'Some formatted arguments' } --... | johnkattenhorn/vso-agent-tasks | Tests/L0/MSBuild-Legacy/PassesArguments.ps1 | PowerShell | mit | 2,162 |
# powershell v2 compatibility
$psVer = $PSVersionTable.PSVersion.Major
if ($psver -ge 3) {
function Get-ChildItemDir {Get-ChildItem -Directory $args}
} else {
function Get-ChildItemDir {Get-ChildItem $args}
}
$packageName = 'keepass-plugin-osk'
$typName = 'SpmImport'
$packageSearch = 'KeePass Password Safe'
try {
#... | dtgm/chocolatey-packages | automatic/_output/keepass-plugin-osk/1.2/tools/chocolateyUninstall.ps1 | PowerShell | apache-2.0 | 1,832 |
# this script should be dot-sourced into the build.ps1 scripts
# right after the parameters declaration
# ie
# . "$PSScriptRoot\build-bootstrap.ps1"
# THIS FILE IS DISTRIBUTED AS PART OF UMBRACO.BUILD
# DO NOT MODIFY IT - ALWAYS USED THE COMMON VERSION
# ################################################... | lars-erik/Umbraco-CMS | build/build-bootstrap.ps1 | PowerShell | mit | 3,123 |
Subsets and Splits
No community queries yet
The top public SQL queries from the community will appear here once available.